@@ -11,7 +11,7 @@
 */
 extern char old_help[80]; //help text to be set back after editor finishes
 
-void start_composer(void *parent, int wx1, int wy1, int wx2, int wy2, char *toaddr, char *subject);
+void start_composer(WINDOW *parent, int wx1, int wy1, int wx2, int wy2, char *toaddr, char *subject);
 void comp_insert(char *s, bool quote = true);
 void comp_edredraw();
 
