@@ -923,10 +923,12 @@ void ExternCmd::send_stream_data(const Event &ev)
 
     int cnt = write(pip_in[1], data, pcnt);
     if (cnt != pcnt)
+    {
       if (errno == EAGAIN)
         fprintf(stderr, "ExternCmd: application pid %i not responding\n", pid);
       else
         Error(errno, "Error while sending data to application pid %i", pid);
+    }
     delete[] data;
 }
 
@@ -1040,7 +1042,7 @@ void EventGate::add_rbuffer(const char *data, size_t count)
 
 bool EventGate::flush_wbuffer(int fd)
 {
-  if (wbufsize == 0 && fd == -1) return true;
+  if (wbufsize == 0 || fd == -1) return true;
   else
   {
     int w;
